@@ -42,10 +42,10 @@ typedef struct {
 } match_t;
 
 typedef struct {
-    long total_bytes;
-    long total_files;
-    long total_matches;
-    long total_file_matches;
+    size_t total_bytes;
+    size_t total_files;
+    size_t total_matches;
+    size_t total_file_matches;
     struct timeval time_start;
     struct timeval time_end;
 } ag_stats;
@@ -69,6 +69,7 @@ void generate_hash(const char *find, const size_t f_len, uint8_t *H, const int c
 
 /* max is already defined on spec-violating compilers such as MinGW */
 size_t ag_max(size_t a, size_t b);
+size_t ag_min(size_t a, size_t b);
 
 const char *boyer_moore_strnstr(const char *s, const char *find, const size_t s_len, const size_t f_len,
                                 const size_t alpha_skip_lookup[], const size_t *find_skip_lookup, const int case_insensitive);
